{
    "$graph": [
        {
            "class": "Workflow",
            "label": "exomeseq-gatk4/v2.2.0",
            "doc": "Whole Exome Sequence analysis using GATK4 - v2.2.0",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "enum",
                            "name": "#ExomeseqStudyType.yml/ExomeseqStudyType",
                            "label": "The type of study",
                            "symbols": [
                                "#ExomeseqStudyType.yml/ExomeseqStudyType/Small Familial",
                                "#ExomeseqStudyType.yml/ExomeseqStudyType/Large Population"
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#FASTQReadPairType.yml/FASTQReadPairType",
                            "fields": [
                                {
                                    "name": "#FASTQReadPairType.yml/FASTQReadPairType/name",
                                    "type": "string"
                                },
                                {
                                    "name": "#FASTQReadPairType.yml/FASTQReadPairType/read1_files",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                },
                                {
                                    "name": "#FASTQReadPairType.yml/FASTQReadPairType/read2_files",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                }
                            ]
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#main/bait_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/indel_resource_mills"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/interval_padding"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/known_sites"
                },
                {
                    "type": "string",
                    "id": "#main/library"
                },
                {
                    "type": "string",
                    "id": "#main/platform"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#FASTQReadPairType.yml/FASTQReadPairType"
                    },
                    "id": "#main/read_pairs"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference_genome"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/resource_dbsnp"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/snp_resource_1kg"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/snp_resource_hapmap"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/snp_resource_omni"
                },
                {
                    "type": "#ExomeseqStudyType.yml/ExomeseqStudyType",
                    "id": "#main/study_type"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#main/target_intervals"
                },
                {
                    "type": "int",
                    "id": "#main/threads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "FS",
                        "ReadPosRankSum",
                        "MQRankSum",
                        "QD",
                        "SOR"
                    ],
                    "id": "#main/variant_recalibration_annotations_indels"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "QD",
                        "MQRankSum",
                        "ReadPosRankSum",
                        "FS",
                        "MQ",
                        "SOR"
                    ],
                    "id": "#main/variant_recalibration_annotations_snps"
                }
            ],
            "steps": [
                {
                    "run": "#exomeseq-gatk4-03-organizedirectories.cwl",
                    "in": [
                        {
                            "source": "#main/preprocessing/markduplicates_bam",
                            "id": "#main/organize_directories/bams_markduplicates"
                        },
                        {
                            "source": "#main/preprocessing/recalibrated_reads",
                            "id": "#main/organize_directories/bams_recalibrated"
                        },
                        {
                            "source": "#main/preprocessing/fastp_html_report",
                            "id": "#main/organize_directories/fastp_html_reports"
                        },
                        {
                            "source": "#main/preprocessing/fastp_json_report",
                            "id": "#main/organize_directories/fastp_json_reports"
                        },
                        {
                            "source": "#main/preprocessing/markduplicates_metrics",
                            "id": "#main/organize_directories/metrics_markduplicates"
                        },
                        {
                            "source": "#main/preprocessing/raw_variants",
                            "id": "#main/organize_directories/raw_variants"
                        }
                    ],
                    "out": [
                        "#main/organize_directories/fastp_html_reports_dir",
                        "#main/organize_directories/fastp_json_reports_dir",
                        "#main/organize_directories/bams_markduplicates_dir",
                        "#main/organize_directories/metrics_markduplicates_dir",
                        "#main/organize_directories/raw_variants_dir",
                        "#main/organize_directories/bams_recalibrated_dir"
                    ],
                    "id": "#main/organize_directories"
                },
                {
                    "run": "#exomeseq-gatk4-00-prepare-reference-data.cwl",
                    "in": [
                        {
                            "source": "#main/bait_intervals",
                            "id": "#main/prepare_reference_data/bait_intervals"
                        },
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/prepare_reference_data/reference_genome"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/prepare_reference_data/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/prepare_reference_data/target_interval_list",
                        "#main/prepare_reference_data/bait_interval_list"
                    ],
                    "id": "#main/prepare_reference_data"
                },
                {
                    "run": "#exomeseq-gatk4-01-preprocessing.cwl",
                    "scatter": "#main/preprocessing/read_pair",
                    "in": [
                        {
                            "source": "#main/prepare_reference_data/bait_interval_list",
                            "id": "#main/preprocessing/bait_interval_list"
                        },
                        {
                            "source": "#main/interval_padding",
                            "id": "#main/preprocessing/interval_padding"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/preprocessing/intervals"
                        },
                        {
                            "source": "#main/known_sites",
                            "id": "#main/preprocessing/known_sites"
                        },
                        {
                            "source": "#main/library",
                            "id": "#main/preprocessing/library"
                        },
                        {
                            "source": "#main/platform",
                            "id": "#main/preprocessing/platform"
                        },
                        {
                            "source": "#main/read_pairs",
                            "id": "#main/preprocessing/read_pair"
                        },
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/preprocessing/reference_genome"
                        },
                        {
                            "source": "#main/resource_dbsnp",
                            "id": "#main/preprocessing/resource_dbsnp"
                        },
                        {
                            "source": "#main/prepare_reference_data/target_interval_list",
                            "id": "#main/preprocessing/target_interval_list"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/preprocessing/threads"
                        }
                    ],
                    "out": [
                        "#main/preprocessing/fastp_html_report",
                        "#main/preprocessing/fastp_json_report",
                        "#main/preprocessing/markduplicates_bam",
                        "#main/preprocessing/markduplicates_metrics",
                        "#main/preprocessing/recalibration_table",
                        "#main/preprocessing/recalibrated_reads",
                        "#main/preprocessing/raw_variants",
                        "#main/preprocessing/haplotypes_bam"
                    ],
                    "id": "#main/preprocessing"
                },
                {
                    "run": "#exomeseq-gatk4-02-variantdiscovery.cwl",
                    "in": [
                        {
                            "source": "#main/indel_resource_mills",
                            "id": "#main/variant_discovery/indel_resource_mills"
                        },
                        {
                            "source": "#main/interval_padding",
                            "id": "#main/variant_discovery/interval_padding"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/variant_discovery/intervals"
                        },
                        {
                            "source": "#main/library",
                            "id": "#main/variant_discovery/name"
                        },
                        {
                            "source": "#main/preprocessing/raw_variants",
                            "id": "#main/variant_discovery/raw_variants"
                        },
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/variant_discovery/reference_genome"
                        },
                        {
                            "source": "#main/resource_dbsnp",
                            "id": "#main/variant_discovery/resource_dbsnp"
                        },
                        {
                            "source": "#main/snp_resource_1kg",
                            "id": "#main/variant_discovery/snp_resource_1kg"
                        },
                        {
                            "source": "#main/snp_resource_hapmap",
                            "id": "#main/variant_discovery/snp_resource_hapmap"
                        },
                        {
                            "source": "#main/snp_resource_omni",
                            "id": "#main/variant_discovery/snp_resource_omni"
                        },
                        {
                            "source": "#main/study_type",
                            "id": "#main/variant_discovery/study_type"
                        },
                        {
                            "source": "#main/prepare_reference_data/target_interval_list",
                            "id": "#main/variant_discovery/target_interval_list"
                        },
                        {
                            "source": "#main/variant_recalibration_annotations_indels",
                            "id": "#main/variant_discovery/variant_recalibration_annotations_indels"
                        },
                        {
                            "source": "#main/variant_recalibration_annotations_snps",
                            "id": "#main/variant_discovery/variant_recalibration_annotations_snps"
                        }
                    ],
                    "out": [
                        "#main/variant_discovery/joint_raw_variants",
                        "#main/variant_discovery/variant_recalibration_snps_tranches",
                        "#main/variant_discovery/variant_recalibration_snps_recalibration",
                        "#main/variant_discovery/variant_recalibration_combined_vcf",
                        "#main/variant_discovery/variant_recalibration_indels_tranches",
                        "#main/variant_discovery/variant_recalibration_snps_indels_recalibration",
                        "#main/variant_discovery/variant_recalibration_indels_vcf",
                        "#main/variant_discovery/detail_metrics",
                        "#main/variant_discovery/summary_metrics"
                    ],
                    "id": "#main/variant_discovery"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#main/organize_directories/bams_markduplicates_dir",
                    "doc": "BAM and bai files from markduplicates",
                    "id": "#main/bams_markduplicates_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/organize_directories/bams_recalibrated_dir",
                    "doc": "BAM files containing recalibrated reads",
                    "id": "#main/bams_recalibrated_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/organize_directories/fastp_html_reports_dir",
                    "id": "#main/fastp_html_reports_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/organize_directories/fastp_json_reports_dir",
                    "id": "#main/fastp_json_reports_dir"
                },
                {
                    "type": "File",
                    "outputSource": "#main/variant_discovery/variant_recalibration_combined_vcf",
                    "doc": "The output filtered and recalibrated VCF file in which each variant is annotated with its VQSLOD value",
                    "id": "#main/filtered_recalibrated_variants"
                },
                {
                    "type": "File",
                    "outputSource": "#main/variant_discovery/joint_raw_variants",
                    "doc": "GVCF file from joint genotyping calling",
                    "id": "#main/joint_raw_variants"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/organize_directories/metrics_markduplicates_dir",
                    "doc": "metrics files from markduplicates",
                    "id": "#main/markduplicates_metrics_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/organize_directories/raw_variants_dir",
                    "id": "#main/raw_variants_dir"
                },
                {
                    "type": "File",
                    "outputSource": "#main/variant_discovery/detail_metrics",
                    "id": "#main/variant_calling_detail_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/variant_discovery/summary_metrics",
                    "id": "#main/variant_calling_summary_metrics"
                }
            ]
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl/reference_genome"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-00-prepare-reference-data.cwl/make_bait_interval_list/output_interval_list_file",
                    "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl/bait_interval_list"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-00-prepare-reference-data.cwl/make_target_interval_list/output_interval_list_file",
                    "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl/target_interval_list"
                }
            ],
            "steps": [
                {
                    "run": "#picard-BedToIntervalList.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 4000,
                            "outdirMin": 12000,
                            "tmpdirMin": 12000
                        }
                    ],
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-00-prepare-reference-data.cwl/bait_intervals",
                            "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl/make_bait_interval_list/input_file"
                        },
                        {
                            "source": "#exomeseq-gatk4-00-prepare-reference-data.cwl/reference_genome",
                            "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl/make_bait_interval_list/reference_sequence"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-00-prepare-reference-data.cwl/make_bait_interval_list/output_interval_list_file"
                    ],
                    "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl/make_bait_interval_list"
                },
                {
                    "run": "#picard-BedToIntervalList.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 4000,
                            "outdirMin": 12000,
                            "tmpdirMin": 12000
                        }
                    ],
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-00-prepare-reference-data.cwl/target_intervals",
                            "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl/make_target_interval_list/input_file"
                        },
                        {
                            "source": "#exomeseq-gatk4-00-prepare-reference-data.cwl/reference_genome",
                            "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl/make_target_interval_list/reference_sequence"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-00-prepare-reference-data.cwl/make_target_interval_list/output_interval_list_file"
                    ],
                    "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl/make_target_interval_list"
                }
            ],
            "id": "#exomeseq-gatk4-00-prepare-reference-data.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#FASTQReadPairType.yml/FASTQReadPairType"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/bait_interval_list"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/known_sites"
                },
                {
                    "type": "string",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/library"
                },
                {
                    "type": "string",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/platform"
                },
                {
                    "type": "#FASTQReadPairType.yml/FASTQReadPairType",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/read_pair"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/reference_genome"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/resource_dbsnp"
                },
                {
                    "type": "File",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/target_interval_list"
                },
                {
                    "type": "int",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-01-preprocessing.cwl/fastp/html_report",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/fastp_html_report"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-01-preprocessing.cwl/fastp/json_report",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/fastp_json_report"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/output_bam",
                    "doc": "BAM file containing assembled haplotypes and locally realigned reads",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/haplotypes_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/output_dedup_bam_file",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/markduplicates_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/output_metrics_file",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/markduplicates_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/output_variants",
                    "doc": "VCF file from per sample variant calling",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/raw_variants"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr/output_recalibrated_bam",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrated_reads"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_01_analyze/output_recalibration_report",
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibration_table"
                }
            ],
            "steps": [
                {
                    "run": "#concat-gz-files.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 1024
                        }
                    ],
                    "scatter": [
                        "#exomeseq-gatk4-01-preprocessing.cwl/combine_reads/files",
                        "#exomeseq-gatk4-01-preprocessing.cwl/combine_reads/output_filename"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/file_pair_details/reads",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/combine_reads/files"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/combined_reads_output_filenames",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/combine_reads/output_filename"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-01-preprocessing.cwl/combine_reads/output"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/combine_reads"
                },
                {
                    "run": "#fastp-pe.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 4,
                            "ramMin": 2048
                        }
                    ],
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/combine_reads/output",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/fastp/reads"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/file_pair_details/read_pair_name",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/fastp/report_base_filename"
                        },
                        {
                            "default": 4,
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/fastp/threads"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/trimmed_reads_output_filenames",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/fastp/trimmed_reads_filenames"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-01-preprocessing.cwl/fastp/trimmed_reads",
                        "#exomeseq-gatk4-01-preprocessing.cwl/fastp/html_report",
                        "#exomeseq-gatk4-01-preprocessing.cwl/fastp/json_report"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/fastp"
                },
                {
                    "run": "#extract-named-file-pair-details.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/library",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/file_pair_details/library"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/platform",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/file_pair_details/platform"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/read_pair",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/file_pair_details/read_pair"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-01-preprocessing.cwl/file_pair_details/reads",
                        "#exomeseq-gatk4-01-preprocessing.cwl/file_pair_details/read_pair_name",
                        "#exomeseq-gatk4-01-preprocessing.cwl/file_pair_details/read_group_header"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/file_pair_details"
                },
                {
                    "run": "#generate-sample-filenames.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/file_pair_details/read_pair_name",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/sample_name"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/combined_reads_output_filenames",
                        "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/trimmed_reads_output_filenames",
                        "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/mapped_reads_output_filename",
                        "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/sorted_reads_output_filename",
                        "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/dedup_reads_output_filename",
                        "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/dedup_metrics_output_filename",
                        "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/recal_reads_output_filename",
                        "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/recal_table_output_filename",
                        "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/raw_variants_output_filename",
                        "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/haplotypes_bam_output_filename"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames"
                },
                {
                    "run": "#gitc-bwa-mem-samtools.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": "$(inputs.threads)",
                            "ramMin": 15336,
                            "outdirMin": 12288,
                            "tmpdirMin": 12288
                        }
                    ],
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/mapped_reads_output_filename",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/map/output_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/file_pair_details/read_group_header",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/map/read_group_header"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/fastp/trimmed_reads",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/map/reads"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/reference_genome",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/map/reference"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/threads",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/map/threads"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-01-preprocessing.cwl/map/output_sorted_bam"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/map"
                },
                {
                    "run": "#GATK4-MarkDuplicates.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "ramMin": 32768,
                            "outdirMin": 12288,
                            "tmpdirMin": 12288
                        }
                    ],
                    "in": [
                        {
                            "default": "coordinate",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/assume_sort_order"
                        },
                        {
                            "default": "true",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/create_index"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/map/output_sorted_bam",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/input_file"
                        },
                        {
                            "default": "-Xms4g",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/java_opt"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/dedup_metrics_output_filename",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/metrics_filename"
                        },
                        {
                            "default": 2500,
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/optical_duplicate_pixel_distance"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/dedup_reads_output_filename",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/output_filename"
                        },
                        {
                            "default": "SILENT",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/validation_stringency"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/output_dedup_bam_file",
                        "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/output_metrics_file"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates"
                },
                {
                    "run": "#GATK4-BaseRecalibrator.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "ramMin": 12288
                        }
                    ],
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/output_dedup_bam_file",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_01_analyze/input_bam"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/interval_padding",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_01_analyze/interval_padding"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/intervals",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_01_analyze/intervals"
                        },
                        {
                            "default": "-Xms4g",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_01_analyze/java_opt"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/known_sites",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_01_analyze/known_sites"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/recal_table_output_filename",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_01_analyze/output_recalibration_report_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/reference_genome",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_01_analyze/reference"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_01_analyze/output_recalibration_report"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_01_analyze"
                },
                {
                    "run": "#GATK4-ApplyBQSR.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "ramMin": 6144
                        }
                    ],
                    "in": [
                        {
                            "default": true,
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr/add_output_sam_program_record"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_01_analyze/output_recalibration_report",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr/bqsr_report"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/mark_duplicates/output_dedup_bam_file",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr/input_bam"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/interval_padding",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr/interval_padding"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/intervals",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr/intervals"
                        },
                        {
                            "default": "-Xms3g",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr/java_opt"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/recal_reads_output_filename",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr/output_recalibrated_bam_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/reference_genome",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr/reference"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr/output_recalibrated_bam"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr"
                },
                {
                    "run": "#GATK4-HaplotypeCaller.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 18432
                        }
                    ],
                    "in": [
                        {
                            "default": [
                                "StandardAnnotation",
                                "AS_StandardAnnotation"
                            ],
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/annotation_groups"
                        },
                        {
                            "default": "GVCF",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/emit_ref_confidence"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/recalibrate_02_apply_bqsr/output_recalibrated_bam",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/input_bam"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/interval_padding",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/interval_padding"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/intervals",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/intervals"
                        },
                        {
                            "default": "-Xms7g",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/java_opt"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/haplotypes_bam_output_filename",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/output_bam_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/generate_sample_filenames/raw_variants_output_filename",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/output_variants_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-01-preprocessing.cwl/reference_genome",
                            "id": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/reference"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/output_variants",
                        "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling/output_bam"
                    ],
                    "id": "#exomeseq-gatk4-01-preprocessing.cwl/variant_calling"
                }
            ],
            "id": "#exomeseq-gatk4-01-preprocessing.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#ExomeseqStudyType.yml/ExomeseqStudyType"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/indel_resource_mills"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/intervals"
                },
                {
                    "type": "string",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/raw_variants"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/reference_genome"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/resource_dbsnp"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/snp_resource_1kg"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/snp_resource_hapmap"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/snp_resource_omni"
                },
                {
                    "type": "#ExomeseqStudyType.yml/ExomeseqStudyType",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/study_type"
                },
                {
                    "type": "File",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/target_interval_list"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_annotations_indels"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_annotations_snps"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics/output_detail_metrics",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/detail_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/output_vcf",
                    "doc": "VCF file from joint genotyping calling",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_raw_variants"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics/output_summary_metrics",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps/output_recalibrated_variants",
                    "doc": "The output VCF file after INDEL and SNP recalibration",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_combined_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/output_tranches",
                    "doc": "The output tranches file used by ApplyVQSR in INDEL mode",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels_tranches"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels/output_recalibrated_variants",
                    "doc": "The output VCF file after INDEL recalibration",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/output_recalibration",
                    "doc": "The output recalibration file used by ApplyVQSR in INDEL mode",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps_indels_recalibration"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/output_recalibration",
                    "doc": "The output recalibration file used by ApplyVQSR in SNP mode",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps_recalibration"
                },
                {
                    "type": "File",
                    "outputSource": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/output_tranches",
                    "doc": "The output tranches file used by ApplyVQSR in SNP mode",
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps_tranches"
                }
            ],
            "steps": [
                {
                    "run": "#GATK4-ApplyVQSR.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 10240
                        }
                    ],
                    "in": [
                        {
                            "default": true,
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels/create_output_variant_index"
                        },
                        {
                            "default": "-Xmx5g -Xms5g",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels/java_opt"
                        },
                        {
                            "default": "INDEL",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels/mode"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/indels_recalibrated_variants_filename",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels/output_recalibrated_variants_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/output_recalibration",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels/recalibration_file"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/output_tranches",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels/tranches_file"
                        },
                        {
                            "default": 99.7,
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels/truth_sensitivity_filter_level"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/output_vcf",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels/variants"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels/output_recalibrated_variants"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels"
                },
                {
                    "run": "#GATK4-ApplyVQSR.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 10240
                        }
                    ],
                    "in": [
                        {
                            "default": true,
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps/create_output_variant_index"
                        },
                        {
                            "default": "-Xmx5g -Xms5g",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps/java_opt"
                        },
                        {
                            "default": "SNP",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps/mode"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/combined_recalibrated_variants_filename",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps/output_recalibrated_variants_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/output_recalibration",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps/recalibration_file"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/output_tranches",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps/tranches_file"
                        },
                        {
                            "default": 99.7,
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps/truth_sensitivity_filter_level"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_indels/output_recalibrated_variants",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps/variants"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps/output_recalibrated_variants"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps"
                },
                {
                    "run": "#GATK4-CollectVariantCallingMetrics.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 2,
                            "ramMin": 12288
                        }
                    ],
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/resource_dbsnp",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics/dbsnp"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/apply_vqsr_snps/output_recalibrated_variants",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics/input_vcf"
                        },
                        {
                            "default": "-Xmx6g -Xms6g",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics/java_opt"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/name",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics/output_metrics_filename_prefix"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/extract_sequence_dict/extracted",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics/sequence_dictionary"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/target_interval_list",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics/target_intervals"
                        },
                        {
                            "default": 8,
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics/thread_count"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics/output_detail_metrics",
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics/output_summary_metrics"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/collect_metrics"
                },
                {
                    "run": "#GATK4-CombineGVCFs.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 2,
                            "ramMin": 16384
                        }
                    ],
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/raw_variants_filename",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/combine_variants/output_vcf_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/reference_genome",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/combine_variants/reference"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/raw_variants",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/combine_variants/variants"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/combine_variants/output_vcf"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/combine_variants"
                },
                {
                    "run": "#extract-secondary-file.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/reference_genome",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/extract_sequence_dict/file"
                        },
                        {
                            "default": ".dict",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/extract_sequence_dict/pattern"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/extract_sequence_dict/extracted"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/extract_sequence_dict"
                },
                {
                    "run": "#generate-variant-recalibration-annotation-set.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_annotations_indels",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_annotations_indels/base_annotations"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/study_type",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_annotations_indels/study_type"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_annotations_indels/annotations"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_annotations_indels"
                },
                {
                    "run": "#generate-variant-recalibration-annotation-set.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_annotations_snps",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_annotations_snps/base_annotations"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/study_type",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_annotations_snps/study_type"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_annotations_snps/annotations"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_annotations_snps"
                },
                {
                    "run": "#generate-joint-filenames-gatk4.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/name",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/name"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/raw_variants_filename",
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/snps_recalibration_filename",
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/snps_tranches_filename",
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/snps_recalibrated_variants_filename",
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/indels_recalibration_filename",
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/indels_tranches_filename",
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/indels_recalibrated_variants_filename",
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/combined_recalibrated_variants_filename"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames"
                },
                {
                    "run": "#GATK4-GenotypeGVCFs.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 2,
                            "ramMin": 10240
                        }
                    ],
                    "in": [
                        {
                            "default": [
                                "StandardAnnotation",
                                "AS_StandardAnnotation"
                            ],
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/annotation_groups"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/resource_dbsnp",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/dbsnp"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/interval_padding",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/interval_padding"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/intervals",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/intervals"
                        },
                        {
                            "default": "-Xmx5g -Xms5g",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/java_opt"
                        },
                        {
                            "default": true,
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/only_output_calls_starting_in_intervals"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/raw_variants_filename",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/output_vcf_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/reference_genome",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/reference"
                        },
                        {
                            "default": true,
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/use_new_qual_calculator"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/combine_variants/output_vcf",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/variants"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/output_vcf"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping"
                },
                {
                    "run": "#GATK4-VariantRecalibrator-Indels.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 2,
                            "ramMin": 49152
                        }
                    ],
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_annotations_indels/annotations",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/annotations"
                        },
                        {
                            "default": "-Xmx24g -Xms24g",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/java_opt"
                        },
                        {
                            "default": 4,
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/max_gaussians"
                        },
                        {
                            "default": "INDEL",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/mode"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/indels_recalibration_filename",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/output_recalibration_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/indels_tranches_filename",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/output_tranches_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/resource_dbsnp",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/resource_dbsnp"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/indel_resource_mills",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/resource_mills"
                        },
                        {
                            "default": [
                                "100.0",
                                "99.95",
                                "99.9",
                                "99.8",
                                "99.6",
                                "99.5",
                                "99.4",
                                "99.3",
                                "99.0",
                                "98.0",
                                "97.0",
                                "90.0"
                            ],
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/tranches"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/output_vcf",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/variants"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/output_recalibration",
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels/output_tranches"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_indels"
                },
                {
                    "run": "#GATK4-VariantRecalibrator-SNPs.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 2,
                            "ramMin": 6144
                        }
                    ],
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_annotations_snps/annotations",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/annotations"
                        },
                        {
                            "default": "-Xmx3g -Xms3g",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/java_opt"
                        },
                        {
                            "default": 6,
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/max_gaussians"
                        },
                        {
                            "default": "SNP",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/mode"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/snps_recalibration_filename",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/output_recalibration_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/generate_joint_filenames/snps_tranches_filename",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/output_tranches_filename"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/snp_resource_1kg",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/resource_1kg"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/resource_dbsnp",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/resource_dbsnp"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/snp_resource_hapmap",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/resource_hapmap"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/snp_resource_omni",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/resource_omni"
                        },
                        {
                            "default": [
                                "100.0",
                                "99.95",
                                "99.9",
                                "99.8",
                                "99.6",
                                "99.5",
                                "99.4",
                                "99.3",
                                "99.0",
                                "98.0",
                                "97.0",
                                "90.0"
                            ],
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/tranches"
                        },
                        {
                            "source": "#exomeseq-gatk4-02-variantdiscovery.cwl/joint_genotyping/output_vcf",
                            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/variants"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/output_recalibration",
                        "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps/output_tranches"
                    ],
                    "id": "#exomeseq-gatk4-02-variantdiscovery.cwl/variant_recalibration_snps"
                }
            ],
            "id": "#exomeseq-gatk4-02-variantdiscovery.cwl"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/bams_markduplicates"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/bams_recalibrated"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/fastp_html_reports"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/fastp_json_reports"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/metrics_markduplicates"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/raw_variants"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#exomeseq-gatk4-03-organizedirectories.cwl/org_bams_markduplicates/outdir",
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/bams_markduplicates_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#exomeseq-gatk4-03-organizedirectories.cwl/org_bams_recalibrated/outdir",
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/bams_recalibrated_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#exomeseq-gatk4-03-organizedirectories.cwl/org_fastp_html_reports/outdir",
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/fastp_html_reports_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#exomeseq-gatk4-03-organizedirectories.cwl/org_fastp_json_reports/outdir",
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/fastp_json_reports_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#exomeseq-gatk4-03-organizedirectories.cwl/org_metrics_markduplicates/outdir",
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/metrics_markduplicates_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#exomeseq-gatk4-03-organizedirectories.cwl/org_raw_variants/outdir",
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/raw_variants_dir"
                }
            ],
            "steps": [
                {
                    "run": "#files-to-directory.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-03-organizedirectories.cwl/bams_markduplicates",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_bams_markduplicates/files"
                        },
                        {
                            "default": "bams-markduplicates",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_bams_markduplicates/name"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-03-organizedirectories.cwl/org_bams_markduplicates/outdir"
                    ],
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_bams_markduplicates"
                },
                {
                    "run": "#files-to-directory.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-03-organizedirectories.cwl/bams_recalibrated",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_bams_recalibrated/files"
                        },
                        {
                            "default": "bams-recalibrated",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_bams_recalibrated/name"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-03-organizedirectories.cwl/org_bams_recalibrated/outdir"
                    ],
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_bams_recalibrated"
                },
                {
                    "run": "#files-to-directory.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-03-organizedirectories.cwl/fastp_html_reports",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_fastp_html_reports/files"
                        },
                        {
                            "default": "fastp-html-reports",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_fastp_html_reports/name"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-03-organizedirectories.cwl/org_fastp_html_reports/outdir"
                    ],
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_fastp_html_reports"
                },
                {
                    "run": "#files-to-directory.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-03-organizedirectories.cwl/fastp_json_reports",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_fastp_json_reports/files"
                        },
                        {
                            "default": "fastp-json-reports",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_fastp_json_reports/name"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-03-organizedirectories.cwl/org_fastp_json_reports/outdir"
                    ],
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_fastp_json_reports"
                },
                {
                    "run": "#files-to-directory.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-03-organizedirectories.cwl/metrics_markduplicates",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_metrics_markduplicates/files"
                        },
                        {
                            "default": "metrics-markduplicates",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_metrics_markduplicates/name"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-03-organizedirectories.cwl/org_metrics_markduplicates/outdir"
                    ],
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_metrics_markduplicates"
                },
                {
                    "run": "#files-to-directory.cwl",
                    "in": [
                        {
                            "source": "#exomeseq-gatk4-03-organizedirectories.cwl/raw_variants",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_raw_variants/files"
                        },
                        {
                            "default": "gvcfs",
                            "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_raw_variants/name"
                        }
                    ],
                    "out": [
                        "#exomeseq-gatk4-03-organizedirectories.cwl/org_raw_variants/outdir"
                    ],
                    "id": "#exomeseq-gatk4-03-organizedirectories.cwl/org_raw_variants"
                }
            ],
            "id": "#exomeseq-gatk4-03-organizedirectories.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "prefix": "--add-output-sam-program-record"
                    },
                    "id": "#GATK4-ApplyBQSR.cwl/add_output_sam_program_record"
                },
                {
                    "type": "File",
                    "doc": "BQSR recalibration report",
                    "inputBinding": {
                        "prefix": "-bqsr"
                    },
                    "id": "#GATK4-ApplyBQSR.cwl/bqsr_report"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "doc": "input bam",
                    "id": "#GATK4-ApplyBQSR.cwl/input_bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Amount of padding (in bp) to add to each interval you are including. Defaults to 0",
                    "inputBinding": {
                        "prefix": "-ip"
                    },
                    "id": "#GATK4-ApplyBQSR.cwl/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "-L"
                            }
                        }
                    ],
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GATK4-ApplyBQSR.cwl/intervals"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-ApplyBQSR.cwl/java_opt"
                },
                {
                    "type": "string",
                    "doc": "Output BAM filename",
                    "default": "recalibrated.bam",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#GATK4-ApplyBQSR.cwl/output_recalibrated_bam_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-R"
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#GATK4-ApplyBQSR.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int",
                            "inputBinding": {
                                "prefix": "--static-quantized-quals"
                            }
                        }
                    ],
                    "doc": "Use static quantized quality scores to a given number of levels (with -bqsr)",
                    "id": "#GATK4-ApplyBQSR.cwl/static_quantized_quals"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "prefix": "--use-original-qualities"
                    },
                    "id": "#GATK4-ApplyBQSR.cwl/use_original_qualities"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_recalibrated_bam_filename)"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#GATK4-ApplyBQSR.cwl/output_recalibrated_bam"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "ApplyBQSR",
                    "position": 0
                }
            ],
            "id": "#GATK4-ApplyBQSR.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-index",
                        "position": 5
                    },
                    "doc": "Trust that all the input training sets' unfiltered records contain only polymorphic sites to drastically speed up the computation.  Default value: false.",
                    "id": "#GATK4-ApplyVQSR.cwl/create_output_variant_index"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-ApplyVQSR.cwl/java_opt"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#GATK4-ApplyVQSR.cwl/mode/SNP",
                            "#GATK4-ApplyVQSR.cwl/mode/INDEL",
                            "#GATK4-ApplyVQSR.cwl/mode/BOTH"
                        ]
                    },
                    "inputBinding": {
                        "prefix": "-mode",
                        "position": 7
                    },
                    "doc": "Recalibration mode to employ  Default value: SNP. Possible values: {SNP, INDEL, BOTH}",
                    "id": "#GATK4-ApplyVQSR.cwl/mode"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-O",
                        "position": 1
                    },
                    "doc": "The output filtered and recalibrated VCF file in which each variant is annotated with its VQSLOD value  Required",
                    "id": "#GATK4-ApplyVQSR.cwl/output_recalibrated_variants_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--recal-file",
                        "position": 2
                    },
                    "doc": "The input recal file used by ApplyRecalibration  Required.",
                    "id": "#GATK4-ApplyVQSR.cwl/recalibration_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--tranches-file",
                        "position": 3
                    },
                    "doc": "The input tranches file describing where to cut the data",
                    "id": "#GATK4-ApplyVQSR.cwl/tranches_file"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--truth-sensitivity-filter-level",
                        "position": 4
                    },
                    "doc": "The truth sensitivity level at which to start filtering",
                    "id": "#GATK4-ApplyVQSR.cwl/truth_sensitivity_filter_level"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-V",
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "One or more VCF files containing variants  This argument must be specified at least once.",
                    "id": "#GATK4-ApplyVQSR.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_recalibrated_variants_filename)"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK4-ApplyVQSR.cwl/output_recalibrated_variants"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "ApplyVQSR",
                    "position": 0
                }
            ],
            "id": "#GATK4-ApplyVQSR.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "doc": "input bam",
                    "id": "#GATK4-BaseRecalibrator.cwl/input_bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Amount of padding (in bp) to add to each interval you are including. Defaults to 0",
                    "inputBinding": {
                        "prefix": "-ip"
                    },
                    "id": "#GATK4-BaseRecalibrator.cwl/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "-L"
                            }
                        }
                    ],
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GATK4-BaseRecalibrator.cwl/intervals"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-BaseRecalibrator.cwl/java_opt"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "--known-sites"
                            }
                        }
                    ],
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "Any number of VCF files representing known SNPs and/or indels. Could be e.g. dbSNP and/or official 1000 Genomes indel calls. SNPs in these files will be ignored unless the --mismatchFraction argument is used. optional parameter.",
                    "id": "#GATK4-BaseRecalibrator.cwl/known_sites"
                },
                {
                    "type": "string",
                    "doc": "Recalibration Report Filename",
                    "default": "recal.csv",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#GATK4-BaseRecalibrator.cwl/output_recalibration_report_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-R"
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#GATK4-BaseRecalibrator.cwl/reference"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "prefix": "--use-original-qualities"
                    },
                    "id": "#GATK4-BaseRecalibrator.cwl/use_original_qualities"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_recalibration_report_filename)"
                    },
                    "id": "#GATK4-BaseRecalibrator.cwl/output_recalibration_report"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "BaseRecalibrator",
                    "position": 0
                }
            ],
            "id": "#GATK4-BaseRecalibrator.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--DBSNP",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "Reference dbSNP file in dbSNP or VCF format.  Required.",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/dbsnp"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--INPUT",
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "Input vcf file for analysis  Required.",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/input_vcf"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/java_opt"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--OUTPUT",
                        "position": 4
                    },
                    "doc": "Path (except for the file extension) of output metrics files to write.",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/output_metrics_filename_prefix"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--SEQUENCE_DICTIONARY",
                        "position": 3
                    },
                    "doc": "If present, speeds loading of dbSNP file, will look for dictionary in vcf if not present here.",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/sequence_dictionary"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--TARGET_INTERVALS",
                        "position": 6
                    },
                    "doc": "Target intervals to restrict analysis to.",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/target_intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--THREAD_COUNT",
                        "position": 5
                    },
                    "doc": "Number of threads to use (Undocumented in gatk CLI help)",
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/thread_count"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_metrics_filename_prefix + '.variant_calling_detail_metrics')"
                    },
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/output_detail_metrics"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_metrics_filename_prefix + '.variant_calling_summary_metrics')"
                    },
                    "id": "#GATK4-CollectVariantCallingMetrics.cwl/output_summary_metrics"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "CollectVariantCallingMetrics",
                    "position": 0
                }
            ],
            "id": "#GATK4-CollectVariantCallingMetrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "doc": "File to which variants should be written  Required.",
                    "id": "#GATK4-CombineGVCFs.cwl/output_vcf_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-R"
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "doc": "Reference sequence file  Required.",
                    "id": "#GATK4-CombineGVCFs.cwl/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--variant"
                        }
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK4-CombineGVCFs.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_filename)"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK4-CombineGVCFs.cwl/output_vcf"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "CombineGVCFs",
                    "position": 0
                }
            ],
            "id": "#GATK4-CombineGVCFs.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "-G"
                            }
                        }
                    ],
                    "doc": "One or more groups of annotations to apply to variant calls  This argument may be specified 0 or more times. Default value: [StandardAnnotation].",
                    "id": "#GATK4-GenotypeGVCFs.cwl/annotation_groups"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-D"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "dbSNP file. Default value: null",
                    "id": "#GATK4-GenotypeGVCFs.cwl/dbsnp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Amount of padding (in bp) to add to each interval you are including. Defaults to 0",
                    "inputBinding": {
                        "prefix": "-ip"
                    },
                    "id": "#GATK4-GenotypeGVCFs.cwl/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "-L"
                            }
                        }
                    ],
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GATK4-GenotypeGVCFs.cwl/intervals"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-GenotypeGVCFs.cwl/java_opt"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--only-output-calls-starting-in-intervals"
                    },
                    "doc": "Restrict variant output to sites that start within provided intervals  Default value: false.",
                    "id": "#GATK4-GenotypeGVCFs.cwl/only_output_calls_starting_in_intervals"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "doc": "File to which variants should be written  Required.",
                    "id": "#GATK4-GenotypeGVCFs.cwl/output_vcf_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-R"
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "doc": "Reference sequence file  Required.",
                    "id": "#GATK4-GenotypeGVCFs.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-new-qual-calculator"
                    },
                    "doc": "If provided, we will use the new AF model instead of the so-called exact model  Default value: false.",
                    "id": "#GATK4-GenotypeGVCFs.cwl/use_new_qual_calculator"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-V",
                        "position": 2
                    },
                    "doc": "One VCF file containing variants  Required.",
                    "id": "#GATK4-GenotypeGVCFs.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_filename)"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK4-GenotypeGVCFs.cwl/output_vcf"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "GenotypeGVCFs",
                    "position": 0
                }
            ],
            "id": "#GATK4-GenotypeGVCFs.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "-G"
                            }
                        }
                    ],
                    "doc": "One or more groups of annotations to apply to variant calls  This argument may be specified 0 or more times. Default value: [StandardAnnotation, StandardHCAnnotation].",
                    "id": "#GATK4-HaplotypeCaller.cwl/annotation_groups"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-D"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "dbSNP file. Default value: null",
                    "id": "#GATK4-HaplotypeCaller.cwl/dbsnp"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-ERC"
                    },
                    "doc": "Mode for emitting reference confidence scores  Default value: NONE. Possible values: {NONE, BP_RESOLUTION, GVCF}",
                    "id": "#GATK4-HaplotypeCaller.cwl/emit_ref_confidence"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "doc": "BAM/SAM/CRAM file containing reads. Required.",
                    "id": "#GATK4-HaplotypeCaller.cwl/input_bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Amount of padding (in bp) to add to each interval you are including. Defaults to 0",
                    "inputBinding": {
                        "prefix": "-ip"
                    },
                    "id": "#GATK4-HaplotypeCaller.cwl/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "-L"
                            }
                        }
                    ],
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GATK4-HaplotypeCaller.cwl/intervals"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-HaplotypeCaller.cwl/java_opt"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-bamout"
                    },
                    "doc": "File to which assembled haplotypes should be written.",
                    "id": "#GATK4-HaplotypeCaller.cwl/output_bam_filename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "doc": "File to which variants should be written  Required. Use .g.vcf to make a GVCF file.",
                    "id": "#GATK4-HaplotypeCaller.cwl/output_variants_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-R"
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "doc": "Reference sequence file  Required.",
                    "id": "#GATK4-HaplotypeCaller.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_bam_filename)"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#GATK4-HaplotypeCaller.cwl/output_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_variants_filename)"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK4-HaplotypeCaller.cwl/output_variants"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "HaplotypeCaller",
                    "position": 0
                }
            ],
            "id": "#GATK4-HaplotypeCaller.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--ASSUME_SORT_ORDER"
                    },
                    "id": "#GATK4-MarkDuplicates.cwl/assume_sort_order"
                },
                {
                    "type": "string",
                    "default": "false",
                    "inputBinding": {
                        "prefix": "--CREATE_INDEX"
                    },
                    "doc": "Create an index",
                    "id": "#GATK4-MarkDuplicates.cwl/create_index"
                },
                {
                    "type": "File",
                    "doc": "One or more input SAM or BAM files to analyze. Must be coordinate sorted.",
                    "inputBinding": {
                        "prefix": "--INPUT"
                    },
                    "id": "#GATK4-MarkDuplicates.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-MarkDuplicates.cwl/java_opt"
                },
                {
                    "type": "string",
                    "doc": "Output metrics filename",
                    "default": "marked_dup_metrics.txt",
                    "inputBinding": {
                        "prefix": "--METRICS_FILE"
                    },
                    "id": "#GATK4-MarkDuplicates.cwl/metrics_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--OPTICAL_DUPLICATE_PIXEL_DISTANCE"
                    },
                    "id": "#GATK4-MarkDuplicates.cwl/optical_duplicate_pixel_distance"
                },
                {
                    "type": "string",
                    "doc": "Output filename",
                    "default": "marked_duplicates.bam",
                    "inputBinding": {
                        "prefix": "--OUTPUT"
                    },
                    "id": "#GATK4-MarkDuplicates.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "If true do not write duplicates to the output file instead of writing them with appropriate flags set.  (Default true).",
                    "inputBinding": {
                        "prefix": "--REMOVE_DUPLICATES:",
                        "shellQuote": false
                    },
                    "id": "#GATK4-MarkDuplicates.cwl/remove_duplicates"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--VALIDATION_STRINGENCY"
                    },
                    "id": "#GATK4-MarkDuplicates.cwl/validation_stringency"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#GATK4-MarkDuplicates.cwl/output_dedup_bam_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.metrics_filename)"
                    },
                    "id": "#GATK4-MarkDuplicates.cwl/output_metrics_file"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "MarkDuplicates",
                    "position": 0
                }
            ],
            "id": "#GATK4-MarkDuplicates.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-an"
                        }
                    },
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "The names of the annotations which should used for calculations",
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/annotations"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/java_opt"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-gaussians",
                        "position": 8
                    },
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/max_gaussians"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#GATK4-VariantRecalibrator-Indels.cwl/mode/SNP",
                            "#GATK4-VariantRecalibrator-Indels.cwl/mode/INDEL",
                            "#GATK4-VariantRecalibrator-Indels.cwl/mode/BOTH"
                        ]
                    },
                    "inputBinding": {
                        "prefix": "-mode",
                        "position": 7
                    },
                    "doc": "Recalibration mode to employ  Default value: SNP. Possible values: {SNP, INDEL, BOTH}",
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/mode"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-O",
                        "position": 2
                    },
                    "doc": "The output recal file used by ApplyRecalibration  Required.",
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/output_recalibration_filename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--tranches-file",
                        "position": 3
                    },
                    "doc": "The output tranches file used by ApplyRecalibration  Required.",
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/output_tranches_filename"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/resource_dbsnp"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "hapmap reference data",
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/resource_mills"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-tranche"
                        }
                    },
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/tranches"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--trust-all-polymorphic",
                        "position": 4
                    },
                    "doc": "Trust that all the input training sets' unfiltered records contain only polymorphic sites to drastically speed up the computation.  Default value: false.",
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/trust_all_polymorphic"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-V",
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "One or more VCF files containing variants  Required.",
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_recalibration_filename)"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/output_recalibration"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_tranches_filename)"
                    },
                    "id": "#GATK4-VariantRecalibrator-Indels.cwl/output_tranches"
                }
            ],
            "arguments": [
                "VariantRecalibrator",
                "-resource",
                "mills,known=false,training=true,truth=true,prior=12.0:$(inputs.resource_mills.path)",
                "-resource",
                "dbsnp,known=true,training=false,truth=false,prior=2.0:$(inputs.resource_dbsnp.path)"
            ],
            "id": "#GATK4-VariantRecalibrator-Indels.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.0.4.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "4.0.4.0"
                            ],
                            "https://schema.org/citation": "https://doi.org/10.1101/gr.107524.110",
                            "package": "gatk"
                        }
                    ]
                }
            ],
            "baseCommand": "gatk",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-an"
                        }
                    },
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "The names of the annotations which should used for calculations",
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/annotations"
                },
                {
                    "type": "string",
                    "doc": "String of options to pass to JVM at runtime",
                    "inputBinding": {
                        "prefix": "--java-options",
                        "position": -1,
                        "shellQuote": true
                    },
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/java_opt"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-gaussians",
                        "position": 8
                    },
                    "doc": "Max number of Gaussians for the positive model  Default value: 8.",
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/max_gaussians"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#GATK4-VariantRecalibrator-SNPs.cwl/mode/SNP",
                            "#GATK4-VariantRecalibrator-SNPs.cwl/mode/INDEL",
                            "#GATK4-VariantRecalibrator-SNPs.cwl/mode/BOTH"
                        ]
                    },
                    "inputBinding": {
                        "prefix": "-mode",
                        "position": 7
                    },
                    "doc": "Recalibration mode to employ  Default value: SNP. Possible values: {SNP, INDEL, BOTH}",
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/mode"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-O",
                        "position": 2
                    },
                    "doc": "The output recal file used by ApplyRecalibration  Required.",
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/output_recalibration_filename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--tranches-file",
                        "position": 3
                    },
                    "doc": "The output tranches file used by ApplyRecalibration  Required.",
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/output_tranches_filename"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "1000 genome reference data",
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/resource_1kg"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "dbSNP reference data",
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/resource_dbsnp"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "hapmap reference data",
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/resource_hapmap"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "omni reference data",
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/resource_omni"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-tranche"
                        }
                    },
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/tranches"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--trust-all-polymorphic",
                        "position": 4
                    },
                    "doc": "Trust that all the input training sets' unfiltered records contain only polymorphic sites to drastically speed up the computation.  Default value: false.",
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/trust_all_polymorphic"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-V",
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "doc": "One or more VCF files containing variants  Required.",
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_recalibration_filename)"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/output_recalibration"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_tranches_filename)"
                    },
                    "id": "#GATK4-VariantRecalibrator-SNPs.cwl/output_tranches"
                }
            ],
            "arguments": [
                "VariantRecalibrator",
                "-resource",
                "hapmap,known=false,training=true,truth=true,prior=15.0:$(inputs.resource_hapmap.path)",
                "-resource",
                "omni,known=false,training=true,truth=true,prior=12.0:$(inputs.resource_omni.path)",
                "-resource",
                "1000G,known=false,training=true,truth=false,prior=10.0:$(inputs.resource_1kg.path)",
                "-resource",
                "dbsnp,known=true,training=false,truth=false,prior=7.0:$(inputs.resource_dbsnp.path)"
            ],
            "id": "#GATK4-VariantRecalibrator-SNPs.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "combinefiles.sh",
                            "entry": "set -o pipefail\nif [ \"$#\" -eq 1 ]; then\n  cat \"$@\"\nelse\n  zcat \"$@\" | gzip\nfi\n"
                        }
                    ]
                }
            ],
            "baseCommand": "bash",
            "arguments": [
                "combinefiles.sh"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2,
                        "shellQuote": false
                    },
                    "id": "#concat-gz-files.cwl/files"
                },
                {
                    "type": "string",
                    "id": "#concat-gz-files.cwl/output_filename"
                }
            ],
            "stdout": "$(inputs.output_filename)",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#concat-gz-files.cwl/output"
                }
            ],
            "id": "#concat-gz-files.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/fastp:0.20.0--hdbcaa40_0"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "0.20.0"
                            ],
                            "package": "fastp",
                            "https://schema.org/citation": "https://doi.org/10.1093/bioinformatics/bty560"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "doc": "By default, the adapter sequence auto-detection is enabled for SE data only turn on this option to enable it for PE data",
                    "default": true,
                    "inputBinding": {
                        "prefix": "--detect_adapter_for_pe"
                    },
                    "id": "#fastp-pe.cwl/detect_adapter_for_pe"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "read1 and read2 input files array",
                    "id": "#fastp-pe.cwl/reads"
                },
                {
                    "type": "string",
                    "doc": "Prefix to use for HTML and JSON report files",
                    "id": "#fastp-pe.cwl/report_base_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "worker thread number, default is 2 (int [=2])",
                    "inputBinding": {
                        "prefix": "-w"
                    },
                    "id": "#fastp-pe.cwl/threads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "doc": "Array of output file names. The output will be gzip-compressed if its file name ends with .gz",
                    "id": "#fastp-pe.cwl/trimmed_reads_filenames"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.report_base_filename + \".html\")"
                    },
                    "id": "#fastp-pe.cwl/html_report"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.report_base_filename + \".json\")"
                    },
                    "id": "#fastp-pe.cwl/json_report"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$(inputs.trimmed_reads_filenames)"
                    },
                    "id": "#fastp-pe.cwl/trimmed_reads"
                }
            ],
            "baseCommand": "fastp",
            "arguments": [
                "-I",
                "$(inputs.reads[0])",
                "-i",
                "$(inputs.reads[1])",
                "-O",
                "$(inputs.trimmed_reads_filenames[0])",
                "-o",
                "$(inputs.trimmed_reads_filenames[1])",
                "-j",
                "$(inputs.report_base_filename + \".json\")",
                "-h",
                "$(inputs.report_base_filename + \".html\")"
            ],
            "id": "#fastp-pe.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/genomes-in-the-cloud:2.3.1-1512499786"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "bwa-mem-samtools.sh",
                            "entry": "set -xo pipefail\n/usr/gitc/bwa mem $@ | samtools sort -O BAM -\n"
                        }
                    ]
                }
            ],
            "baseCommand": "bash",
            "arguments": [
                "bwa-mem-samtools.sh"
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "0.7.15"
                            ],
                            "package": "bwa",
                            "https://schema.org/citation": "https://dx.doi.org/10.1093/bioinformatics/btp324"
                        },
                        {
                            "version": [
                                "1.3.1"
                            ],
                            "package": "samtools",
                            "https://schema.org/citation": "https://doi.org/10.1093/bioinformatics/btp352"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-I",
                        "itemSeparator": ","
                    },
                    "id": "#gitc-bwa-mem-samtools.cwl/min_std_max_min"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-k"
                    },
                    "doc": "-k INT        minimum seed length [19]",
                    "id": "#gitc-bwa-mem-samtools.cwl/minimum_seed_length"
                },
                {
                    "type": "string",
                    "id": "#gitc-bwa-mem-samtools.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-R"
                    },
                    "doc": "-R STR        read group header line such as '@RG\\tID:foo\\tSM:bar' [null]",
                    "id": "#gitc-bwa-mem-samtools.cwl/read_group_header"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#gitc-bwa-mem-samtools.cwl/reads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#gitc-bwa-mem-samtools.cwl/reference"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "doc": "smart pairing (ignoring in2.fq)",
                    "id": "#gitc-bwa-mem-samtools.cwl/smart_pairing"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "prefix": "-Y"
                    },
                    "id": "#gitc-bwa-mem-samtools.cwl/soft_clipping"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-t"
                    },
                    "doc": "-t INT        number of threads [1]",
                    "id": "#gitc-bwa-mem-samtools.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-v"
                    },
                    "doc": "verbose level: 1=error, 2=warning, 3=message, 4+=debugging [3]",
                    "id": "#gitc-bwa-mem-samtools.cwl/verbosity"
                }
            ],
            "stdout": "$(inputs.output_filename)",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#gitc-bwa-mem-samtools.cwl/output_sorted_bam"
                }
            ],
            "id": "#gitc-bwa-mem-samtools.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/picard:2.10.7"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "2.10.7"
                            ],
                            "package": "picard",
                            "https://schema.org/citation": "http://broadinstitute.github.io/picard"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "doc": "The bed file to be converted to interval_list format.  Required.",
                    "inputBinding": {
                        "prefix": "I=",
                        "shellQuote": false
                    },
                    "id": "#picard-BedToIntervalList.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Interval list output filename.",
                    "default": "list.interval_list",
                    "inputBinding": {
                        "prefix": "O=",
                        "shellQuote": false
                    },
                    "id": "#picard-BedToIntervalList.cwl/output_filename"
                },
                {
                    "type": "File",
                    "doc": "The reference sequences in fasta format.",
                    "inputBinding": {
                        "prefix": "SD=",
                        "shellQuote": false
                    },
                    "id": "#picard-BedToIntervalList.cwl/reference_sequence"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#picard-BedToIntervalList.cwl/output_interval_list_file"
                }
            ],
            "baseCommand": [
                "java",
                "-Xmx4g"
            ],
            "arguments": [
                {
                    "valueFrom": "/opt/picard/picard.jar",
                    "position": -1,
                    "prefix": "-jar"
                },
                {
                    "valueFrom": "BedToIntervalList",
                    "position": 0
                }
            ],
            "id": "#picard-BedToIntervalList.cwl"
        },
        {
            "class": "ExpressionTool",
            "label": "Given a FASTQReadPairType returns a 2D array of the files contained within",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#FASTQReadPairType.yml/FASTQReadPairType"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#extract-named-file-pair-details.cwl/library"
                },
                {
                    "type": "string",
                    "id": "#extract-named-file-pair-details.cwl/platform"
                },
                {
                    "type": "#FASTQReadPairType.yml/FASTQReadPairType",
                    "id": "#extract-named-file-pair-details.cwl/read_pair"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "id": "#extract-named-file-pair-details.cwl/read_group_header"
                },
                {
                    "type": "string",
                    "id": "#extract-named-file-pair-details.cwl/read_pair_name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#extract-named-file-pair-details.cwl/reads"
                }
            ],
            "expression": "${\n  var readPairName = inputs.read_pair.name;\n  var readGroupHeader = \"@RG\" +\n    \"\\\\tID:\" + readPairName +\n    \"\\\\tLB:\" + inputs.library +\n    \"\\\\tPL:\" + inputs.platform +\n    \"\\\\tPU:\" + readPairName +\n    \"\\\\tSM:\" + readPairName;\n  return {\n    reads: [\n      inputs.read_pair.read1_files,\n      inputs.read_pair.read2_files,\n    ],\n    read_pair_name: readPairName,\n    read_group_header: readGroupHeader\n  };\n\n}\n",
            "id": "#extract-named-file-pair-details.cwl"
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#extract-secondary-file.cwl/file"
                },
                {
                    "type": "string",
                    "id": "#extract-secondary-file.cwl/pattern"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract-secondary-file.cwl/extracted"
                }
            ],
            "expression": "${\n  var secondaryFiles = inputs.file.secondaryFiles;\n  var pattern = inputs.pattern;\n  var matches = secondaryFiles.filter(function(each) {\n    return each.basename.match(pattern);\n  });\n  return { \"extracted\" : matches[0] };\n}\n",
            "id": "#extract-secondary-file.cwl"
        },
        {
            "class": "ExpressionTool",
            "label": "Moves an array of Files into a named directory",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#files-to-directory.cwl/files"
                },
                {
                    "type": "string",
                    "id": "#files-to-directory.cwl/name"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "id": "#files-to-directory.cwl/outdir"
                }
            ],
            "expression": "${\n  var result = {\n    outdir: {\n      class: 'Directory',\n      basename: inputs.name,\n      listing: inputs.files\n    }\n  };\n\n  return result;\n}\n",
            "id": "#files-to-directory.cwl"
        },
        {
            "class": "ExpressionTool",
            "label": "Generates a set of file names for joint steps based on an input name",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/name"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/combined_recalibrated_variants_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/indels_recalibrated_variants_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/indels_recalibration_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/indels_tranches_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/raw_variants_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/snps_recalibrated_variants_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/snps_recalibration_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-joint-filenames-gatk4.cwl/snps_tranches_filename"
                }
            ],
            "expression": "${\n  function makeFilename(base, suffix, extension) {\n    return base + '-' + suffix + '.' + extension;\n  }\n  var base = inputs.name\n\n  return {\n    raw_variants_filename: makeFilename(base, 'raw_variants', 'g.vcf'),\n    snps_recalibration_filename: makeFilename(base, 'snps_recal', 'out'),\n    snps_tranches_filename: makeFilename(base, 'snps_tranches', 'out'),\n    snps_recalibrated_variants_filename: makeFilename(base, 'snps_recal_variants', 'vcf'),\n    indels_recalibration_filename: makeFilename(base, 'indels_recal', 'out'),\n    indels_tranches_filename: makeFilename(base, 'indels_tranches', 'out'),\n    indels_recalibrated_variants_filename: makeFilename(base, 'indels_recal_variants', 'vcf'),\n    combined_recalibrated_variants_filename: makeFilename(base, 'indels_snps_recal_variants', 'vcf')\n  };\n}\n",
            "id": "#generate-joint-filenames-gatk4.cwl"
        },
        {
            "class": "ExpressionTool",
            "label": "Generates a set of file names for preprocessing steps based on an input sample name",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/sample_name"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#generate-sample-filenames.cwl/combined_reads_output_filenames"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/dedup_metrics_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/dedup_reads_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/fixedtag_reads_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/haplotypes_bam_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/hs_metrics_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/mapped_reads_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/raw_variants_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/recal_reads_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/recal_table_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/sorted_reads_output_filename"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#generate-sample-filenames.cwl/trimmed_reads_output_filenames"
                }
            ],
            "expression": "${\n  function makeFilename(base, suffix, extension) {\n    return base + '-' + suffix + '.' + extension;\n  }\n  var base = inputs.sample_name\n\n  return {\n    combined_reads_output_filenames: [\n      makeFilename(base, 'R1', 'fastq.gz'),\n      makeFilename(base, 'R2', 'fastq.gz'),\n    ],\n    trimmed_reads_output_filenames: [\n      makeFilename(base, 'R1-trimmed', 'fastq.gz'),\n      makeFilename(base, 'R2-trimmed', 'fastq.gz'),\n    ],\n    mapped_reads_output_filename: makeFilename(base, 'mapped', 'bam'),\n    sorted_reads_output_filename: makeFilename(base, 'sorted', 'bam'),\n    dedup_reads_output_filename: makeFilename(base, 'dedup', 'bam'),\n    dedup_metrics_output_filename: makeFilename(base, 'dedup-metrics', 'out'),\n    recal_reads_output_filename: makeFilename(base, 'recal', 'bam'),\n    recal_table_output_filename: makeFilename(base, 'recal', 'table'),\n    raw_variants_output_filename: makeFilename(base, 'raw_variants', 'g.vcf'),\n    haplotypes_bam_output_filename:  makeFilename(base, 'haplotypes', 'bam'),\n    hs_metrics_output_filename: makeFilename(base, 'hs', 'txt'),\n    fixedtag_reads_output_filename: makeFilename(base, 'fixed_tags', 'bam')\n  };\n}\n",
            "id": "#generate-sample-filenames.cwl"
        },
        {
            "class": "ExpressionTool",
            "label": "Given an ExomeseqStudyType returns an array of the annotations to use.",
            "doc": "The InbreedingCoeff is a population level statistic that requires at least 10 samples in order to be computed. For projects with fewer samples, or that includes many closely related samples (such as a family) please omit this annotation from the command line. From https://software.broadinstitute.org/gatk/documentation/article?id=1259\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#ExomeseqStudyType.yml/ExomeseqStudyType"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#generate-variant-recalibration-annotation-set.cwl/base_annotations"
                },
                {
                    "type": "#ExomeseqStudyType.yml/ExomeseqStudyType",
                    "id": "#generate-variant-recalibration-annotation-set.cwl/study_type"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#generate-variant-recalibration-annotation-set.cwl/annotations"
                }
            ],
            "expression": "${\n  var annotations = inputs.base_annotations;\n  var inputStudyType = inputs.study_type;\n  if(inputStudyType === \"Large Population\") {\n    annotations.push(\"InbreedingCoeff\");\n  }\n  return {\"annotations\": annotations };\n}\n",
            "id": "#generate-variant-recalibration-annotation-set.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schema.rdf"
    ]
}
